@@ -1,6 +1,6 @@
 package App::Info::Handler;
 
-# $Id: Handler.pm 819 2004-11-03 18:02:20Z theory $
+# $Id: Handler.pm 855 2004-11-19 23:32:11Z theory $
 
 =head1 NAME
 
@@ -35,7 +35,7 @@ handlers, read on!
 
 use strict;
 use vars qw($VERSION);
-$VERSION = '0.27';
+$VERSION = '0.28';
 
 my %handlers;
 
@@ -265,12 +265,12 @@ App::Info::Request object for each event type.
 
 =head1 BUGS
 
-Report all bugs via the CPAN Request Tracker at
+Please send bug reports to <bug-app-info@rt.cpan.org> or file them at
 L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=App-Info>.
 
 =head1 AUTHOR
 
-David Wheeler <L<david@wheeler.net|"david@wheeler.net">>
+David Wheeler <david@justatheory.com>
 
 =head1 SEE ALSO
 
